@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 #########################################################################
 
@@ -69,6 +69,8 @@ our %T =
      => "fehlerhafte Nutzung von %s als %s",
      bad_usage_of__1_pkg_is__2
      => "fehlerhafte Nutzung von %s, \$pkg ist '%s'",
+     can_t_open__1__2
+     => "",	# TODO: "can't open '%s': %s"
      can_t_remove__1_from_old_parent__2
      => "kann '%s' nicht von altem Elternelement trennen",
      can_t_remove__1_no_such_node_in__2
@@ -89,6 +91,8 @@ our %T =
      => 'ungültiges Objekt (%s) in Aufruf von %s',
      invalid_object__1_in_call_to__2__3
      => 'ungültiges Objekt (%s) in Aufruf von %s::%s',
+     invalid_pair_in__1_attribute
+     => "",	# TODO: "invalid pair in '%s' attribute"
      invalid_parameter__1_in_call_to__2
      => "ungültiger Parameter '%s'in Aufruf von %s",
      invalid_parameter__1_in_call_to__2__3
@@ -105,6 +109,8 @@ our %T =
      => "ungültiger Wert %s für Parameter '%s' in Aufruf von %s::%s",
      leave_box
      => 'Box verlassen',
+     leave_dialog
+     => '',	# TODO: 'leave dialogue'
      leave_listbox
      => 'Listbox verlassen',
      leave_window
